@@ -1,15 +1,15 @@
 require 'spec_helper'
 
-describe 'postgresql::server::db', :type => :define do
+describe 'postgresql::server::db', type: :define do
   let :facts do
     {
-      :osfamily => 'Debian',
-      :operatingsystem => 'Debian',
-      :operatingsystemrelease => '6.0',
-      :kernel => 'Linux',
-      :concat_basedir => tmpfilename('contrib'),
-      :id => 'root',
-      :path => '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
+      osfamily: 'Debian',
+      operatingsystem: 'Debian',
+      operatingsystemrelease: '6.0',
+      kernel: 'Linux',
+      concat_basedir: tmpfilename('contrib'),
+      id: 'root',
+      path: '/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin',
     }
   end
 
@@ -18,12 +18,11 @@ describe 'postgresql::server::db', :type => :define do
   end
 
   context 'without dbname param' do
-
     let :params do
       {
-        :user => 'test',
-        :password => 'test',
-        :owner => 'tester',
+        user: 'test',
+        password: 'test',
+        owner: 'tester',
       }
     end
 
@@ -35,17 +34,15 @@ describe 'postgresql::server::db', :type => :define do
     it { is_expected.to contain_postgresql__server__database('test').with_owner('tester') }
     it { is_expected.to contain_postgresql__server__role('test').that_comes_before('Postgresql::Server::Database[test]') }
     it { is_expected.to contain_postgresql__server__database_grant('GRANT test - ALL - test') }
-
   end
 
   context 'dbname' do
-
     let :params do
       {
-        :dbname => 'testtest',
-        :user => 'test',
-        :password => 'test',
-        :owner => 'tester',
+        dbname: 'testtest',
+        user: 'test',
+        password: 'test',
+        owner: 'tester',
       }
     end
 
